@@ -132,7 +132,11 @@ _RequiredLaunchConfigTypeDef = TypedDict(
 )
 _OptionalLaunchConfigTypeDef = TypedDict(
     "_OptionalLaunchConfigTypeDef",
-    {"environmentVariables": Dict[str, str], "portForwardingConfig": PortForwardingConfigTypeDef},
+    {
+        "environmentVariables": Dict[str, str],
+        "portForwardingConfig": PortForwardingConfigTypeDef,
+        "streamUI": bool,
+    },
     total=False,
 )
 
@@ -310,10 +314,12 @@ CreateDeploymentJobResponseTypeDef = TypedDict(
             "RobotDeploymentNoResponse",
             "RobotAgentConnectionTimeout",
             "GreengrassDeploymentFailed",
+            "InvalidGreengrassGroup",
             "MissingRobotArchitecture",
             "MissingRobotApplicationArchitecture",
             "MissingRobotDeploymentResource",
             "GreengrassGroupVersionDoesNotExist",
+            "LambdaDeleted",
             "ExtractingBundleFailure",
             "PreLaunchFileFailure",
             "PostLaunchFileFailure",
@@ -552,10 +558,12 @@ RobotDeploymentTypeDef = TypedDict(
             "RobotDeploymentNoResponse",
             "RobotAgentConnectionTimeout",
             "GreengrassDeploymentFailed",
+            "InvalidGreengrassGroup",
             "MissingRobotArchitecture",
             "MissingRobotApplicationArchitecture",
             "MissingRobotDeploymentResource",
             "GreengrassGroupVersionDoesNotExist",
+            "LambdaDeleted",
             "ExtractingBundleFailure",
             "PreLaunchFileFailure",
             "PostLaunchFileFailure",
@@ -585,10 +593,12 @@ DescribeDeploymentJobResponseTypeDef = TypedDict(
             "RobotDeploymentNoResponse",
             "RobotAgentConnectionTimeout",
             "GreengrassDeploymentFailed",
+            "InvalidGreengrassGroup",
             "MissingRobotArchitecture",
             "MissingRobotApplicationArchitecture",
             "MissingRobotDeploymentResource",
             "GreengrassGroupVersionDoesNotExist",
+            "LambdaDeleted",
             "ExtractingBundleFailure",
             "PreLaunchFileFailure",
             "PostLaunchFileFailure",
@@ -917,10 +927,12 @@ DeploymentJobTypeDef = TypedDict(
             "RobotDeploymentNoResponse",
             "RobotAgentConnectionTimeout",
             "GreengrassDeploymentFailed",
+            "InvalidGreengrassGroup",
             "MissingRobotArchitecture",
             "MissingRobotApplicationArchitecture",
             "MissingRobotDeploymentResource",
             "GreengrassGroupVersionDoesNotExist",
+            "LambdaDeleted",
             "ExtractingBundleFailure",
             "PreLaunchFileFailure",
             "PostLaunchFileFailure",
@@ -1108,10 +1120,12 @@ SyncDeploymentJobResponseTypeDef = TypedDict(
             "RobotDeploymentNoResponse",
             "RobotAgentConnectionTimeout",
             "GreengrassDeploymentFailed",
+            "InvalidGreengrassGroup",
             "MissingRobotArchitecture",
             "MissingRobotApplicationArchitecture",
             "MissingRobotDeploymentResource",
             "GreengrassGroupVersionDoesNotExist",
+            "LambdaDeleted",
             "ExtractingBundleFailure",
             "PreLaunchFileFailure",
             "PostLaunchFileFailure",
